import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.time.chrono
import java.time.format
import java.time.temporal
import java.time.zone
import java.util
import java.util.stream

class Clock(InstantSource):
    def __init__(self) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fixed(fixedInstant: Instant, zone: ZoneId, /) -> Clock: ...
    def getZone(self) -> ZoneId: ...
    def hashCode(self) -> int: ...
    def instant(self) -> Instant: ...
    def millis(self) -> int: ...
    @staticmethod
    def offset(baseClock: Clock, offsetDuration: Duration, /) -> Clock: ...
    @staticmethod
    def system(zone: ZoneId, /) -> Clock: ...
    @staticmethod
    def systemDefaultZone() -> Clock: ...
    @staticmethod
    def systemUTC() -> Clock: ...
    @staticmethod
    def tick(baseClock: Clock, tickDuration: Duration, /) -> Clock: ...
    @staticmethod
    def tickMillis(zone: ZoneId, /) -> Clock: ...
    @staticmethod
    def tickMinutes(zone: ZoneId, /) -> Clock: ...
    @staticmethod
    def tickSeconds(zone: ZoneId, /) -> Clock: ...
    def withZone(self, arg1: ZoneId, /) -> Clock: ...

class DateTimeException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class DayOfWeek(java.lang.Enum[DayOfWeek], java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster):
    FRIDAY: typing.ClassVar[DayOfWeek] = ...
    MONDAY: typing.ClassVar[DayOfWeek] = ...
    SATURDAY: typing.ClassVar[DayOfWeek] = ...
    SUNDAY: typing.ClassVar[DayOfWeek] = ...
    THURSDAY: typing.ClassVar[DayOfWeek] = ...
    TUESDAY: typing.ClassVar[DayOfWeek] = ...
    WEDNESDAY: typing.ClassVar[DayOfWeek] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> DayOfWeek: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getValue(self) -> int: ...
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    def minus(self, days: int | java.jlong | java.lang.Long, /) -> DayOfWeek: ...
    @staticmethod
    def of(dayOfWeek: int | java.jint | java.lang.Integer, /) -> DayOfWeek: ...
    def plus(self, days: int | java.jlong | java.lang.Long, /) -> DayOfWeek: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> DayOfWeek: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[DayOfWeek]: ...

class Duration(java.io.Serializable, java.lang.Comparable[Duration], java.time.temporal.TemporalAmount):
    ZERO: typing.ClassVar[Duration] = ...
    def abs(self) -> Duration: ...
    def addTo(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    @staticmethod
    def between(startInclusive: java.time.temporal.Temporal, endExclusive: java.time.temporal.Temporal, /) -> Duration: ...
    def compareTo(self, otherDuration: Duration, /) -> int: ...
    @typing.overload
    def dividedBy(self, divisor: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @typing.overload
    def dividedBy(self, divisor: Duration, /) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(amount: java.time.temporal.TemporalAmount, /) -> Duration: ...
    def get(self, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def getNano(self) -> int: ...
    def getSeconds(self) -> int: ...
    def getUnits(self) -> java.util.List[java.time.temporal.TemporalUnit]: ...
    def hashCode(self) -> int: ...
    def isNegative(self) -> bool: ...
    def isZero(self) -> bool: ...
    @typing.overload
    def minus(self, duration: Duration, /) -> Duration: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> Duration: ...
    def minusDays(self, daysToSubtract: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def minusHours(self, hoursToSubtract: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def minusMillis(self, millisToSubtract: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def minusMinutes(self, minutesToSubtract: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def minusNanos(self, nanosToSubtract: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def minusSeconds(self, secondsToSubtract: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def multipliedBy(self, multiplicand: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def negated(self) -> Duration: ...
    @staticmethod
    def of(amount: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> Duration: ...
    @staticmethod
    def ofDays(days: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @staticmethod
    def ofHours(hours: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @staticmethod
    def ofMillis(millis: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @staticmethod
    def ofMinutes(minutes: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @staticmethod
    def ofNanos(nanos: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @typing.overload
    @staticmethod
    def ofSeconds(seconds: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @typing.overload
    @staticmethod
    def ofSeconds(seconds: int | java.jlong | java.lang.Long, nanoAdjustment: int | java.jlong | java.lang.Long, /) -> Duration: ...
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> Duration: ...
    @typing.overload
    def plus(self, duration: Duration, /) -> Duration: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> Duration: ...
    def plusDays(self, daysToAdd: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def plusHours(self, hoursToAdd: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def plusMillis(self, millisToAdd: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def plusMinutes(self, minutesToAdd: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def plusNanos(self, nanosToAdd: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def plusSeconds(self, secondsToAdd: int | java.jlong | java.lang.Long, /) -> Duration: ...
    def subtractFrom(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def toDays(self) -> int: ...
    def toDaysPart(self) -> int: ...
    def toHours(self) -> int: ...
    def toHoursPart(self) -> int: ...
    def toMillis(self) -> int: ...
    def toMillisPart(self) -> int: ...
    def toMinutes(self) -> int: ...
    def toMinutesPart(self) -> int: ...
    def toNanos(self) -> int: ...
    def toNanosPart(self) -> int: ...
    def toSeconds(self) -> int: ...
    def toSecondsPart(self) -> int: ...
    def toString(self) -> str: ...
    def truncatedTo(self, unit: java.time.temporal.TemporalUnit, /) -> Duration: ...
    def withNanos(self, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> Duration: ...
    def withSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> Duration: ...

class Instant(java.io.Serializable, java.lang.Comparable[Instant], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    EPOCH: typing.ClassVar[Instant] = ...
    MAX: typing.ClassVar[Instant] = ...
    MIN: typing.ClassVar[Instant] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atOffset(self, offset: ZoneOffset, /) -> OffsetDateTime: ...
    def atZone(self, zone: ZoneId, /) -> ZonedDateTime: ...
    def compareTo(self, otherInstant: Instant, /) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> Instant: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getEpochSecond(self) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getNano(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, otherInstant: Instant, /) -> bool: ...
    def isBefore(self, otherInstant: Instant, /) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> Instant: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> Instant: ...
    def minusMillis(self, millisToSubtract: int | java.jlong | java.lang.Long, /) -> Instant: ...
    def minusNanos(self, nanosToSubtract: int | java.jlong | java.lang.Long, /) -> Instant: ...
    def minusSeconds(self, secondsToSubtract: int | java.jlong | java.lang.Long, /) -> Instant: ...
    @typing.overload
    @staticmethod
    def now() -> Instant: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> Instant: ...
    @staticmethod
    def ofEpochMilli(epochMilli: int | java.jlong | java.lang.Long, /) -> Instant: ...
    @typing.overload
    @staticmethod
    def ofEpochSecond(epochSecond: int | java.jlong | java.lang.Long, /) -> Instant: ...
    @typing.overload
    @staticmethod
    def ofEpochSecond(epochSecond: int | java.jlong | java.lang.Long, nanoAdjustment: int | java.jlong | java.lang.Long, /) -> Instant: ...
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> Instant: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> Instant: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> Instant: ...
    def plusMillis(self, millisToAdd: int | java.jlong | java.lang.Long, /) -> Instant: ...
    def plusNanos(self, nanosToAdd: int | java.jlong | java.lang.Long, /) -> Instant: ...
    def plusSeconds(self, secondsToAdd: int | java.jlong | java.lang.Long, /) -> Instant: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toEpochMilli(self) -> int: ...
    def toString(self) -> str: ...
    def truncatedTo(self, unit: java.time.temporal.TemporalUnit, /) -> Instant: ...
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> Instant: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> Instant: ...

class InstantSource(java.lang.Object):
    @staticmethod
    def fixed(fixedInstant: Instant, /) -> InstantSource: ...
    def instant(self) -> Instant: ...
    def millis(self) -> int: ...
    @staticmethod
    def offset(baseSource: InstantSource, offsetDuration: Duration, /) -> InstantSource: ...
    @staticmethod
    def system() -> InstantSource: ...
    @staticmethod
    def tick(baseSource: InstantSource, tickDuration: Duration, /) -> InstantSource: ...
    def withZone(self, zone: ZoneId, /) -> Clock: ...

class LocalDate(java.io.Serializable, java.time.chrono.ChronoLocalDate, java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    EPOCH: typing.ClassVar[LocalDate] = ...
    MAX: typing.ClassVar[LocalDate] = ...
    MIN: typing.ClassVar[LocalDate] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    @typing.overload
    def atStartOfDay(self) -> LocalDateTime: ...
    @typing.overload
    def atStartOfDay(self, zone: ZoneId, /) -> ZonedDateTime: ...
    @typing.overload
    def atTime(self, time: LocalTime, /) -> LocalDateTime: ...
    @typing.overload
    def atTime(self, time: OffsetTime, /) -> OffsetDateTime: ...
    @typing.overload
    def atTime(self, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @typing.overload
    def atTime(self, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @typing.overload
    def atTime(self, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    def compareTo(self, other: java.time.chrono.ChronoLocalDate, /) -> int: ...
    @typing.overload
    def datesUntil(self, endExclusive: LocalDate, /) -> java.util.stream.Stream[LocalDate]: ...
    @typing.overload
    def datesUntil(self, endExclusive: LocalDate, step: Period, /) -> java.util.stream.Stream[LocalDate]: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> LocalDate: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getChronology(self) -> java.time.chrono.IsoChronology: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getEra(self) -> java.time.chrono.Era: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: java.time.chrono.ChronoLocalDate, /) -> bool: ...
    def isBefore(self, other: java.time.chrono.ChronoLocalDate, /) -> bool: ...
    def isEqual(self, other: java.time.chrono.ChronoLocalDate, /) -> bool: ...
    def isLeapYear(self) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> LocalDate: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> LocalDate: ...
    def minusDays(self, daysToSubtract: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    def minusMonths(self, monthsToSubtract: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    def minusWeeks(self, weeksToSubtract: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    def minusYears(self, yearsToSubtract: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    @typing.overload
    @staticmethod
    def now() -> LocalDate: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> LocalDate: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> LocalDate: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: Month, dayOfMonth: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    @staticmethod
    def ofEpochDay(epochDay: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    @staticmethod
    def ofInstant(instant: Instant, zone: ZoneId, /) -> LocalDate: ...
    @staticmethod
    def ofYearDay(year: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> LocalDate: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> LocalDate: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> LocalDate: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> LocalDate: ...
    def plusDays(self, daysToAdd: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    def plusMonths(self, monthsToAdd: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    def plusWeeks(self, weeksToAdd: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    def plusYears(self, yearsToAdd: int | java.jlong | java.lang.Long, /) -> LocalDate: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def toEpochSecond(self, time: LocalTime, offset: ZoneOffset, /) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def until(self, endDateExclusive: java.time.chrono.ChronoLocalDate, /) -> Period: ...
    @typing.overload
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def withDayOfMonth(self, dayOfMonth: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    def withDayOfYear(self, dayOfYear: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    def withMonth(self, month: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    def withYear(self, year: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> LocalDate: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> LocalDate: ...

class LocalDateTime(java.io.Serializable, java.time.chrono.ChronoLocalDateTime[LocalDate], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    MAX: typing.ClassVar[LocalDateTime] = ...
    MIN: typing.ClassVar[LocalDateTime] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atOffset(self, offset: ZoneOffset, /) -> OffsetDateTime: ...
    def atZone(self, zone: ZoneId, /) -> ZonedDateTime: ...
    def compareTo(self, other: java.time.chrono.ChronoLocalDateTime[java.lang.Object], /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> LocalDateTime: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getMinute(self) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getNano(self) -> int: ...
    def getSecond(self) -> int: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: java.time.chrono.ChronoLocalDateTime[java.lang.Object], /) -> bool: ...
    def isBefore(self, other: java.time.chrono.ChronoLocalDateTime[java.lang.Object], /) -> bool: ...
    def isEqual(self, other: java.time.chrono.ChronoLocalDateTime[java.lang.Object], /) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> LocalDateTime: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> LocalDateTime: ...
    def minusDays(self, days: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def minusHours(self, hours: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def minusMinutes(self, minutes: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def minusMonths(self, months: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def minusNanos(self, nanos: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def minusSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def minusWeeks(self, weeks: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def minusYears(self, years: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def now() -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def of(date: LocalDate, time: LocalTime, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: Month, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: Month, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: Month, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @staticmethod
    def ofEpochSecond(epochSecond: int | java.jlong | java.lang.Long, nanoOfSecond: int | java.jint | java.lang.Integer, offset: ZoneOffset, /) -> LocalDateTime: ...
    @staticmethod
    def ofInstant(instant: Instant, zone: ZoneId, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> LocalDateTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> LocalDateTime: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> LocalDateTime: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> LocalDateTime: ...
    def plusDays(self, days: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def plusHours(self, hours: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def plusMinutes(self, minutes: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def plusMonths(self, months: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def plusNanos(self, nanos: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def plusSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def plusWeeks(self, weeks: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    def plusYears(self, years: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toLocalDate(self) -> LocalDate: ...
    def toLocalTime(self) -> LocalTime: ...
    def toString(self) -> str: ...
    def truncatedTo(self, unit: java.time.temporal.TemporalUnit, /) -> LocalDateTime: ...
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def withDayOfMonth(self, dayOfMonth: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    def withDayOfYear(self, dayOfYear: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    def withHour(self, hour: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    def withMinute(self, minute: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    def withMonth(self, month: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    def withNano(self, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    def withSecond(self, second: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    def withYear(self, year: int | java.jint | java.lang.Integer, /) -> LocalDateTime: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> LocalDateTime: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> LocalDateTime: ...

class LocalTime(java.io.Serializable, java.lang.Comparable[LocalTime], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    MAX: typing.ClassVar[LocalTime] = ...
    MIDNIGHT: typing.ClassVar[LocalTime] = ...
    MIN: typing.ClassVar[LocalTime] = ...
    NOON: typing.ClassVar[LocalTime] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atDate(self, date: LocalDate, /) -> LocalDateTime: ...
    def atOffset(self, offset: ZoneOffset, /) -> OffsetTime: ...
    def compareTo(self, other: LocalTime, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> LocalTime: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getMinute(self) -> int: ...
    def getNano(self) -> int: ...
    def getSecond(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: LocalTime, /) -> bool: ...
    def isBefore(self, other: LocalTime, /) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> LocalTime: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> LocalTime: ...
    def minusHours(self, hoursToSubtract: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    def minusMinutes(self, minutesToSubtract: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    def minusNanos(self, nanosToSubtract: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    def minusSeconds(self, secondsToSubtract: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    @typing.overload
    @staticmethod
    def now() -> LocalTime: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> LocalTime: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> LocalTime: ...
    @typing.overload
    @staticmethod
    def of(hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, /) -> LocalTime: ...
    @typing.overload
    @staticmethod
    def of(hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, /) -> LocalTime: ...
    @typing.overload
    @staticmethod
    def of(hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> LocalTime: ...
    @staticmethod
    def ofInstant(instant: Instant, zone: ZoneId, /) -> LocalTime: ...
    @staticmethod
    def ofNanoOfDay(nanoOfDay: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    @staticmethod
    def ofSecondOfDay(secondOfDay: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> LocalTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> LocalTime: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> LocalTime: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> LocalTime: ...
    def plusHours(self, hoursToAdd: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    def plusMinutes(self, minutesToAdd: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    def plusNanos(self, nanosToAdd: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    def plusSeconds(self, secondstoAdd: int | java.jlong | java.lang.Long, /) -> LocalTime: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toEpochSecond(self, date: LocalDate, offset: ZoneOffset, /) -> int: ...
    def toNanoOfDay(self) -> int: ...
    def toSecondOfDay(self) -> int: ...
    def toString(self) -> str: ...
    def truncatedTo(self, unit: java.time.temporal.TemporalUnit, /) -> LocalTime: ...
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def withHour(self, hour: int | java.jint | java.lang.Integer, /) -> LocalTime: ...
    def withMinute(self, minute: int | java.jint | java.lang.Integer, /) -> LocalTime: ...
    def withNano(self, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> LocalTime: ...
    def withSecond(self, second: int | java.jint | java.lang.Integer, /) -> LocalTime: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> LocalTime: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> LocalTime: ...

class Month(java.lang.Enum[Month], java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster):
    APRIL: typing.ClassVar[Month] = ...
    AUGUST: typing.ClassVar[Month] = ...
    DECEMBER: typing.ClassVar[Month] = ...
    FEBRUARY: typing.ClassVar[Month] = ...
    JANUARY: typing.ClassVar[Month] = ...
    JULY: typing.ClassVar[Month] = ...
    JUNE: typing.ClassVar[Month] = ...
    MARCH: typing.ClassVar[Month] = ...
    MAY: typing.ClassVar[Month] = ...
    NOVEMBER: typing.ClassVar[Month] = ...
    OCTOBER: typing.ClassVar[Month] = ...
    SEPTEMBER: typing.ClassVar[Month] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def firstDayOfYear(self, leapYear: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def firstMonthOfQuarter(self) -> Month: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> Month: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getValue(self) -> int: ...
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    def length(self, leapYear: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def maxLength(self) -> int: ...
    def minLength(self) -> int: ...
    def minus(self, months: int | java.jlong | java.lang.Long, /) -> Month: ...
    @staticmethod
    def of(month: int | java.jint | java.lang.Integer, /) -> Month: ...
    def plus(self, months: int | java.jlong | java.lang.Long, /) -> Month: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> Month: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[Month]: ...

class MonthDay(java.io.Serializable, java.lang.Comparable[MonthDay], java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster):
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atYear(self, year: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    def compareTo(self, other: MonthDay, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> MonthDay: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: MonthDay, /) -> bool: ...
    def isBefore(self, other: MonthDay, /) -> bool: ...
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    def isValidYear(self, year: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def now() -> MonthDay: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> MonthDay: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> MonthDay: ...
    @typing.overload
    @staticmethod
    def of(month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> MonthDay: ...
    @typing.overload
    @staticmethod
    def of(month: Month, dayOfMonth: int | java.jint | java.lang.Integer, /) -> MonthDay: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> MonthDay: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> MonthDay: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...
    def withDayOfMonth(self, dayOfMonth: int | java.jint | java.lang.Integer, /) -> MonthDay: ...
    def withMonth(self, month: int | java.jint | java.lang.Integer, /) -> MonthDay: ...
    def with_(self, month: Month, /) -> MonthDay: ...

class OffsetDateTime(java.io.Serializable, java.lang.Comparable[OffsetDateTime], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    MAX: typing.ClassVar[OffsetDateTime] = ...
    MIN: typing.ClassVar[OffsetDateTime] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atZoneSameInstant(self, zone: ZoneId, /) -> ZonedDateTime: ...
    def atZoneSimilarLocal(self, zone: ZoneId, /) -> ZonedDateTime: ...
    def compareTo(self, other: OffsetDateTime, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> OffsetDateTime: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getMinute(self) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getNano(self) -> int: ...
    def getOffset(self) -> ZoneOffset: ...
    def getSecond(self) -> int: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: OffsetDateTime, /) -> bool: ...
    def isBefore(self, other: OffsetDateTime, /) -> bool: ...
    def isEqual(self, other: OffsetDateTime, /) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> OffsetDateTime: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> OffsetDateTime: ...
    def minusDays(self, days: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def minusHours(self, hours: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def minusMinutes(self, minutes: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def minusMonths(self, months: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def minusNanos(self, nanos: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def minusSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def minusWeeks(self, weeks: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def minusYears(self, years: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    @typing.overload
    @staticmethod
    def now() -> OffsetDateTime: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> OffsetDateTime: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> OffsetDateTime: ...
    @typing.overload
    @staticmethod
    def of(dateTime: LocalDateTime, offset: ZoneOffset, /) -> OffsetDateTime: ...
    @typing.overload
    @staticmethod
    def of(date: LocalDate, time: LocalTime, offset: ZoneOffset, /) -> OffsetDateTime: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, nanoOfSecond: int | java.jint | java.lang.Integer, offset: ZoneOffset, /) -> OffsetDateTime: ...
    @staticmethod
    def ofInstant(instant: Instant, zone: ZoneId, /) -> OffsetDateTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> OffsetDateTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> OffsetDateTime: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> OffsetDateTime: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> OffsetDateTime: ...
    def plusDays(self, days: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def plusHours(self, hours: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def plusMinutes(self, minutes: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def plusMonths(self, months: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def plusNanos(self, nanos: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def plusSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def plusWeeks(self, weeks: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    def plusYears(self, years: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    @staticmethod
    def timeLineOrder() -> java.util.Comparator[OffsetDateTime]: ...
    def toEpochSecond(self) -> int: ...
    def toInstant(self) -> Instant: ...
    def toLocalDate(self) -> LocalDate: ...
    def toLocalDateTime(self) -> LocalDateTime: ...
    def toLocalTime(self) -> LocalTime: ...
    def toOffsetTime(self) -> OffsetTime: ...
    def toString(self) -> str: ...
    def toZonedDateTime(self) -> ZonedDateTime: ...
    def truncatedTo(self, unit: java.time.temporal.TemporalUnit, /) -> OffsetDateTime: ...
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def withDayOfMonth(self, dayOfMonth: int | java.jint | java.lang.Integer, /) -> OffsetDateTime: ...
    def withDayOfYear(self, dayOfYear: int | java.jint | java.lang.Integer, /) -> OffsetDateTime: ...
    def withHour(self, hour: int | java.jint | java.lang.Integer, /) -> OffsetDateTime: ...
    def withMinute(self, minute: int | java.jint | java.lang.Integer, /) -> OffsetDateTime: ...
    def withMonth(self, month: int | java.jint | java.lang.Integer, /) -> OffsetDateTime: ...
    def withNano(self, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> OffsetDateTime: ...
    def withOffsetSameInstant(self, offset: ZoneOffset, /) -> OffsetDateTime: ...
    def withOffsetSameLocal(self, offset: ZoneOffset, /) -> OffsetDateTime: ...
    def withSecond(self, second: int | java.jint | java.lang.Integer, /) -> OffsetDateTime: ...
    def withYear(self, year: int | java.jint | java.lang.Integer, /) -> OffsetDateTime: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> OffsetDateTime: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> OffsetDateTime: ...

class OffsetTime(java.io.Serializable, java.lang.Comparable[OffsetTime], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    MAX: typing.ClassVar[OffsetTime] = ...
    MIN: typing.ClassVar[OffsetTime] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atDate(self, date: LocalDate, /) -> OffsetDateTime: ...
    def compareTo(self, other: OffsetTime, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> OffsetTime: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getMinute(self) -> int: ...
    def getNano(self) -> int: ...
    def getOffset(self) -> ZoneOffset: ...
    def getSecond(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: OffsetTime, /) -> bool: ...
    def isBefore(self, other: OffsetTime, /) -> bool: ...
    def isEqual(self, other: OffsetTime, /) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> OffsetTime: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> OffsetTime: ...
    def minusHours(self, hours: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...
    def minusMinutes(self, minutes: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...
    def minusNanos(self, nanos: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...
    def minusSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...
    @typing.overload
    @staticmethod
    def now() -> OffsetTime: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> OffsetTime: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> OffsetTime: ...
    @typing.overload
    @staticmethod
    def of(time: LocalTime, offset: ZoneOffset, /) -> OffsetTime: ...
    @typing.overload
    @staticmethod
    def of(hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, nanoOfSecond: int | java.jint | java.lang.Integer, offset: ZoneOffset, /) -> OffsetTime: ...
    @staticmethod
    def ofInstant(instant: Instant, zone: ZoneId, /) -> OffsetTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> OffsetTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> OffsetTime: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> OffsetTime: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> OffsetTime: ...
    def plusHours(self, hours: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...
    def plusMinutes(self, minutes: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...
    def plusNanos(self, nanos: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...
    def plusSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toEpochSecond(self, date: LocalDate, /) -> int: ...
    def toLocalTime(self) -> LocalTime: ...
    def toString(self) -> str: ...
    def truncatedTo(self, unit: java.time.temporal.TemporalUnit, /) -> OffsetTime: ...
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def withHour(self, hour: int | java.jint | java.lang.Integer, /) -> OffsetTime: ...
    def withMinute(self, minute: int | java.jint | java.lang.Integer, /) -> OffsetTime: ...
    def withNano(self, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> OffsetTime: ...
    def withOffsetSameInstant(self, offset: ZoneOffset, /) -> OffsetTime: ...
    def withOffsetSameLocal(self, offset: ZoneOffset, /) -> OffsetTime: ...
    def withSecond(self, second: int | java.jint | java.lang.Integer, /) -> OffsetTime: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> OffsetTime: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> OffsetTime: ...

class Period(java.io.Serializable, java.time.chrono.ChronoPeriod):
    ZERO: typing.ClassVar[Period] = ...
    def addTo(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    @staticmethod
    def between(startDateInclusive: LocalDate, endDateExclusive: LocalDate, /) -> Period: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(amount: java.time.temporal.TemporalAmount, /) -> Period: ...
    def get(self, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def getChronology(self) -> java.time.chrono.IsoChronology: ...
    def getDays(self) -> int: ...
    def getMonths(self) -> int: ...
    def getUnits(self) -> java.util.List[java.time.temporal.TemporalUnit]: ...
    def getYears(self) -> int: ...
    def hashCode(self) -> int: ...
    def isNegative(self) -> bool: ...
    def isZero(self) -> bool: ...
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> Period: ...
    def minusDays(self, daysToSubtract: int | java.jlong | java.lang.Long, /) -> Period: ...
    def minusMonths(self, monthsToSubtract: int | java.jlong | java.lang.Long, /) -> Period: ...
    def minusYears(self, yearsToSubtract: int | java.jlong | java.lang.Long, /) -> Period: ...
    def multipliedBy(self, scalar: int | java.jint | java.lang.Integer, /) -> Period: ...
    def negated(self) -> Period: ...
    def normalized(self) -> Period: ...
    @staticmethod
    def of(years: int | java.jint | java.lang.Integer, months: int | java.jint | java.lang.Integer, days: int | java.jint | java.lang.Integer, /) -> Period: ...
    @staticmethod
    def ofDays(days: int | java.jint | java.lang.Integer, /) -> Period: ...
    @staticmethod
    def ofMonths(months: int | java.jint | java.lang.Integer, /) -> Period: ...
    @staticmethod
    def ofWeeks(weeks: int | java.jint | java.lang.Integer, /) -> Period: ...
    @staticmethod
    def ofYears(years: int | java.jint | java.lang.Integer, /) -> Period: ...
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> Period: ...
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> Period: ...
    def plusDays(self, daysToAdd: int | java.jlong | java.lang.Long, /) -> Period: ...
    def plusMonths(self, monthsToAdd: int | java.jlong | java.lang.Long, /) -> Period: ...
    def plusYears(self, yearsToAdd: int | java.jlong | java.lang.Long, /) -> Period: ...
    def subtractFrom(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def toString(self) -> str: ...
    def toTotalMonths(self) -> int: ...
    def withDays(self, days: int | java.jint | java.lang.Integer, /) -> Period: ...
    def withMonths(self, months: int | java.jint | java.lang.Integer, /) -> Period: ...
    def withYears(self, years: int | java.jint | java.lang.Integer, /) -> Period: ...

class Year(java.io.Serializable, java.lang.Comparable[Year], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    MAX_VALUE: typing.ClassVar[int] = ...
    MIN_VALUE: typing.ClassVar[int] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atDay(self, dayOfYear: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    @typing.overload
    def atMonth(self, month: int | java.jint | java.lang.Integer, /) -> YearMonth: ...
    @typing.overload
    def atMonth(self, month: Month, /) -> YearMonth: ...
    def atMonthDay(self, monthDay: MonthDay, /) -> LocalDate: ...
    def compareTo(self, other: Year, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> Year: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: Year, /) -> bool: ...
    def isBefore(self, other: Year, /) -> bool: ...
    @typing.overload
    def isLeap(self) -> bool: ...
    @typing.overload
    @staticmethod
    def isLeap(year: int | java.jlong | java.lang.Long, /) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    def isValidMonthDay(self, monthDay: MonthDay, /) -> bool: ...
    def length(self) -> int: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> Year: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> Year: ...
    def minusYears(self, yearsToSubtract: int | java.jlong | java.lang.Long, /) -> Year: ...
    @typing.overload
    @staticmethod
    def now() -> Year: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> Year: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> Year: ...
    @staticmethod
    def of(isoYear: int | java.jint | java.lang.Integer, /) -> Year: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> Year: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> Year: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> Year: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> Year: ...
    def plusYears(self, yearsToAdd: int | java.jlong | java.lang.Long, /) -> Year: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> Year: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> Year: ...

class YearMonth(java.io.Serializable, java.lang.Comparable[YearMonth], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atDay(self, dayOfMonth: int | java.jint | java.lang.Integer, /) -> LocalDate: ...
    def atEndOfMonth(self) -> LocalDate: ...
    def compareTo(self, other: YearMonth, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> YearMonth: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: YearMonth, /) -> bool: ...
    def isBefore(self, other: YearMonth, /) -> bool: ...
    def isLeapYear(self) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    def isValidDay(self, dayOfMonth: int | java.jint | java.lang.Integer, /) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> YearMonth: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> YearMonth: ...
    def minusMonths(self, monthsToSubtract: int | java.jlong | java.lang.Long, /) -> YearMonth: ...
    def minusYears(self, yearsToSubtract: int | java.jlong | java.lang.Long, /) -> YearMonth: ...
    @typing.overload
    @staticmethod
    def now() -> YearMonth: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> YearMonth: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> YearMonth: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, /) -> YearMonth: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: Month, /) -> YearMonth: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> YearMonth: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> YearMonth: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> YearMonth: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> YearMonth: ...
    def plusMonths(self, monthsToAdd: int | java.jlong | java.lang.Long, /) -> YearMonth: ...
    def plusYears(self, yearsToAdd: int | java.jlong | java.lang.Long, /) -> YearMonth: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def withMonth(self, month: int | java.jint | java.lang.Integer, /) -> YearMonth: ...
    def withYear(self, year: int | java.jint | java.lang.Integer, /) -> YearMonth: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> YearMonth: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> YearMonth: ...

class ZoneId(java.io.Serializable):
    SHORT_IDS: typing.ClassVar[java.util.Map[java.lang.String, java.lang.String]] = ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> ZoneId: ...
    @staticmethod
    def getAvailableZoneIds() -> java.util.Set[java.lang.String]: ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getId(self) -> str: ...
    def getRules(self) -> java.time.zone.ZoneRules: ...
    def hashCode(self) -> int: ...
    def normalized(self) -> ZoneId: ...
    @typing.overload
    @staticmethod
    def of(zoneId: str | java.lang.String, /) -> ZoneId: ...
    @typing.overload
    @staticmethod
    def of(zoneId: str | java.lang.String, aliasMap: java.util.Map[java.lang.String, java.lang.String], /) -> ZoneId: ...
    @staticmethod
    def ofOffset(prefix: str | java.lang.String, offset: ZoneOffset, /) -> ZoneId: ...
    @staticmethod
    def systemDefault() -> ZoneId: ...
    def toString(self) -> str: ...

class ZoneOffset(ZoneId, java.io.Serializable, java.lang.Comparable[ZoneOffset], java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster):
    MAX: typing.ClassVar[ZoneOffset] = ...
    MIN: typing.ClassVar[ZoneOffset] = ...
    UTC: typing.ClassVar[ZoneOffset] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def compareTo(self, other: ZoneOffset, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> ZoneOffset: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getId(self) -> str: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getRules(self) -> java.time.zone.ZoneRules: ...
    def getTotalSeconds(self) -> int: ...
    def hashCode(self) -> int: ...
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @staticmethod
    def of(offsetId: str | java.lang.String, /) -> ZoneOffset: ...
    @staticmethod
    def ofHours(hours: int | java.jint | java.lang.Integer, /) -> ZoneOffset: ...
    @staticmethod
    def ofHoursMinutes(hours: int | java.jint | java.lang.Integer, minutes: int | java.jint | java.lang.Integer, /) -> ZoneOffset: ...
    @staticmethod
    def ofHoursMinutesSeconds(hours: int | java.jint | java.lang.Integer, minutes: int | java.jint | java.lang.Integer, seconds: int | java.jint | java.lang.Integer, /) -> ZoneOffset: ...
    @staticmethod
    def ofTotalSeconds(totalSeconds: int | java.jint | java.lang.Integer, /) -> ZoneOffset: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...

class ZonedDateTime(java.io.Serializable, java.time.chrono.ChronoZonedDateTime[LocalDate], java.time.temporal.Temporal):
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> ZonedDateTime: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getMinute(self) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getNano(self) -> int: ...
    def getOffset(self) -> ZoneOffset: ...
    def getSecond(self) -> int: ...
    def getYear(self) -> int: ...
    def getZone(self) -> ZoneId: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    @typing.overload
    def minus(self, amountToSubtract: java.time.temporal.TemporalAmount, /) -> ZonedDateTime: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> ZonedDateTime: ...
    def minusDays(self, days: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def minusHours(self, hours: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def minusMinutes(self, minutes: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def minusMonths(self, months: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def minusNanos(self, nanos: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def minusSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def minusWeeks(self, weeks: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def minusYears(self, years: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def now() -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def now(clock: Clock, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def now(zone: ZoneId, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def of(localDateTime: LocalDateTime, zone: ZoneId, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def of(date: LocalDate, time: LocalTime, zone: ZoneId, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def of(year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, nanoOfSecond: int | java.jint | java.lang.Integer, zone: ZoneId, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def ofInstant(instant: Instant, zone: ZoneId, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def ofInstant(localDateTime: LocalDateTime, offset: ZoneOffset, zone: ZoneId, /) -> ZonedDateTime: ...
    @staticmethod
    def ofLocal(localDateTime: LocalDateTime, zone: ZoneId, preferredOffset: ZoneOffset, /) -> ZonedDateTime: ...
    @staticmethod
    def ofStrict(localDateTime: LocalDateTime, offset: ZoneOffset, zone: ZoneId, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, /) -> ZonedDateTime: ...
    @typing.overload
    @staticmethod
    def parse(text: java.lang.CharSequence, formatter: java.time.format.DateTimeFormatter, /) -> ZonedDateTime: ...
    @typing.overload
    def plus(self, amountToAdd: java.time.temporal.TemporalAmount, /) -> ZonedDateTime: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> ZonedDateTime: ...
    def plusDays(self, days: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def plusHours(self, hours: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def plusMinutes(self, minutes: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def plusMonths(self, months: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def plusNanos(self, nanos: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def plusSeconds(self, seconds: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def plusWeeks(self, weeks: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    def plusYears(self, years: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toLocalDate(self) -> LocalDate: ...
    def toLocalDateTime(self) -> LocalDateTime: ...
    def toLocalTime(self) -> LocalTime: ...
    def toOffsetDateTime(self) -> OffsetDateTime: ...
    def toString(self) -> str: ...
    def truncatedTo(self, unit: java.time.temporal.TemporalUnit, /) -> ZonedDateTime: ...
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def withDayOfMonth(self, dayOfMonth: int | java.jint | java.lang.Integer, /) -> ZonedDateTime: ...
    def withDayOfYear(self, dayOfYear: int | java.jint | java.lang.Integer, /) -> ZonedDateTime: ...
    def withEarlierOffsetAtOverlap(self) -> ZonedDateTime: ...
    def withFixedOffsetZone(self) -> ZonedDateTime: ...
    def withHour(self, hour: int | java.jint | java.lang.Integer, /) -> ZonedDateTime: ...
    def withLaterOffsetAtOverlap(self) -> ZonedDateTime: ...
    def withMinute(self, minute: int | java.jint | java.lang.Integer, /) -> ZonedDateTime: ...
    def withMonth(self, month: int | java.jint | java.lang.Integer, /) -> ZonedDateTime: ...
    def withNano(self, nanoOfSecond: int | java.jint | java.lang.Integer, /) -> ZonedDateTime: ...
    def withSecond(self, second: int | java.jint | java.lang.Integer, /) -> ZonedDateTime: ...
    def withYear(self, year: int | java.jint | java.lang.Integer, /) -> ZonedDateTime: ...
    def withZoneSameInstant(self, zone: ZoneId, /) -> ZonedDateTime: ...
    def withZoneSameLocal(self, zone: ZoneId, /) -> ZonedDateTime: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> ZonedDateTime: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> ZonedDateTime: ...



import typing

import android.content
import android.database.sqlite
import android.net
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.util

class AbstractCursor(CrossProcessCursor):
    mClosed: bool = ...
    mContentResolver: android.content.ContentResolver = ...
    mPos: int = ...
    def __init__(self) -> None: ...
    def checkPosition(self) -> None: ...
    def close(self) -> None: ...
    def copyStringToBuffer(self, columnIndex: int | java.jint | java.lang.Integer, buffer: CharArrayBuffer, /) -> None: ...
    def deactivate(self) -> None: ...
    def fillWindow(self, position: int | java.jint | java.lang.Integer, window: CursorWindow, /) -> None: ...
    def finalize(self) -> None: ...
    def getBlob(self, column: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def getColumnCount(self) -> int: ...
    def getColumnIndex(self, columnName: str | java.lang.String, /) -> int: ...
    def getColumnIndexOrThrow(self, columnName: str | java.lang.String, /) -> int: ...
    def getColumnName(self, columnIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getColumnNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getCount(self) -> int: ...
    def getDouble(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getFloat(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...
    def getInt(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getNotificationUri(self) -> android.net.Uri: ...
    def getNotificationUris(self) -> java.util.List[android.net.Uri]: ...
    def getPosition(self) -> int: ...
    def getShort(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getType(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getUpdatedField(self, columnIndex: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getWantsAllOnMoveCalls(self) -> bool: ...
    def getWindow(self) -> CursorWindow | None: ...
    def isAfterLast(self) -> bool: ...
    def isBeforeFirst(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isFieldUpdated(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isFirst(self) -> bool: ...
    def isLast(self) -> bool: ...
    def isNull(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def move(self, offset: int | java.jint | java.lang.Integer, /) -> bool: ...
    def moveToFirst(self) -> bool: ...
    def moveToLast(self) -> bool: ...
    def moveToNext(self) -> bool: ...
    def moveToPosition(self, position: int | java.jint | java.lang.Integer, /) -> bool: ...
    def moveToPrevious(self) -> bool: ...
    def onChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onMove(self, oldPosition: int | java.jint | java.lang.Integer, newPosition: int | java.jint | java.lang.Integer, /) -> bool: ...
    def registerContentObserver(self, observer: ContentObserver, /) -> None: ...
    def registerDataSetObserver(self, observer: DataSetObserver, /) -> None: ...
    def requery(self) -> bool: ...
    def respond(self, extras: android.os.Bundle, /) -> android.os.Bundle: ...
    def setExtras(self, extras: android.os.Bundle, /) -> None: ...
    def setNotificationUri(self, cr: android.content.ContentResolver, notifyUri: android.net.Uri, /) -> None: ...
    def setNotificationUris(self, cr: android.content.ContentResolver, notifyUris: java.util.List[android.net.Uri], /) -> None: ...
    def unregisterContentObserver(self, observer: ContentObserver, /) -> None: ...
    def unregisterDataSetObserver(self, observer: DataSetObserver, /) -> None: ...

    class SelfContentObserver(ContentObserver):
        def __init__(self, cursor: AbstractCursor, /) -> None: ...
        def deliverSelfNotifications(self) -> bool: ...
        def onChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class AbstractWindowedCursor(AbstractCursor):
    mWindow: CursorWindow = ...
    def __init__(self) -> None: ...
    def checkPosition(self) -> None: ...
    def copyStringToBuffer(self, columnIndex: int | java.jint | java.lang.Integer, buffer: CharArrayBuffer, /) -> None: ...
    def getBlob(self, columnIndex: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def getDouble(self, columnIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getFloat(self, columnIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getInt(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getShort(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, columnIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getType(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getWindow(self) -> CursorWindow: ...
    def hasWindow(self) -> bool: ...
    def isBlob(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isFloat(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isLong(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isNull(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isString(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setWindow(self, window: CursorWindow, /) -> None: ...

class CharArrayBuffer(java.lang.Object):
    data: java.chaquopy.JavaArrayJChar = ...
    sizeCopied: int = ...
    @typing.overload
    def __init__(self, size: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJChar, /) -> None: ...

class ContentObservable(Observable[ContentObserver]):
    def __init__(self) -> None: ...
    @typing.overload
    def dispatchChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def dispatchChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, uri: android.net.Uri, /) -> None: ...
    def notifyChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def registerObserver(self, observer: ContentObserver, /) -> None: ...

class ContentObserver(java.lang.Object):
    def __init__(self, handler: android.os.Handler, /) -> None: ...
    def deliverSelfNotifications(self) -> bool: ...
    @typing.overload
    def dispatchChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def dispatchChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, uri: android.net.Uri, /) -> None: ...
    @typing.overload
    def dispatchChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, uri: android.net.Uri, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def dispatchChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, uris: java.util.Collection[android.net.Uri], flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, uri: android.net.Uri, /) -> None: ...
    @typing.overload
    def onChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, uri: android.net.Uri, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, uris: java.util.Collection[android.net.Uri], flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CrossProcessCursor(Cursor):
    def fillWindow(self, arg1: int | java.jint | java.lang.Integer, arg2: CursorWindow, /) -> None: ...
    def getWindow(self) -> CursorWindow | None: ...
    def onMove(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...

class CrossProcessCursorWrapper(CrossProcessCursor, CursorWrapper):
    def __init__(self, cursor: Cursor, /) -> None: ...
    def fillWindow(self, position: int | java.jint | java.lang.Integer, window: CursorWindow, /) -> None: ...
    def getWindow(self) -> CursorWindow: ...
    def onMove(self, oldPosition: int | java.jint | java.lang.Integer, newPosition: int | java.jint | java.lang.Integer, /) -> bool: ...

class Cursor(java.io.Closeable):
    FIELD_TYPE_BLOB: typing.ClassVar[int] = ...
    FIELD_TYPE_FLOAT: typing.ClassVar[int] = ...
    FIELD_TYPE_INTEGER: typing.ClassVar[int] = ...
    FIELD_TYPE_NULL: typing.ClassVar[int] = ...
    FIELD_TYPE_STRING: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def copyStringToBuffer(self, arg1: int | java.jint | java.lang.Integer, arg2: CharArrayBuffer, /) -> None: ...
    def deactivate(self) -> None: ...
    def getBlob(self, arg1: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def getColumnCount(self) -> int: ...
    def getColumnIndex(self, arg1: str | java.lang.String, /) -> int: ...
    def getColumnIndexOrThrow(self, arg1: str | java.lang.String, /) -> int: ...
    def getColumnName(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getColumnNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getCount(self) -> int: ...
    def getDouble(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getFloat(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...
    def getInt(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getNotificationUri(self) -> android.net.Uri: ...
    def getNotificationUris(self) -> java.util.List[android.net.Uri] | None: ...
    def getPosition(self) -> int: ...
    def getShort(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getType(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getWantsAllOnMoveCalls(self) -> bool: ...
    def isAfterLast(self) -> bool: ...
    def isBeforeFirst(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isFirst(self) -> bool: ...
    def isLast(self) -> bool: ...
    def isNull(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def move(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def moveToFirst(self) -> bool: ...
    def moveToLast(self) -> bool: ...
    def moveToNext(self) -> bool: ...
    def moveToPosition(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def moveToPrevious(self) -> bool: ...
    def registerContentObserver(self, arg1: ContentObserver, /) -> None: ...
    def registerDataSetObserver(self, arg1: DataSetObserver, /) -> None: ...
    def requery(self) -> bool: ...
    def respond(self, arg1: android.os.Bundle, /) -> android.os.Bundle: ...
    def setExtras(self, arg1: android.os.Bundle, /) -> None: ...
    def setNotificationUri(self, arg1: android.content.ContentResolver, arg2: android.net.Uri, /) -> None: ...
    def setNotificationUris(self, cr: android.content.ContentResolver, uris: java.util.List[android.net.Uri], /) -> None: ...
    def unregisterContentObserver(self, arg1: ContentObserver, /) -> None: ...
    def unregisterDataSetObserver(self, arg1: DataSetObserver, /) -> None: ...

class CursorIndexOutOfBoundsException(java.lang.IndexOutOfBoundsException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, index: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, /) -> None: ...

class CursorJoiner(java.lang.Iterable[CursorJoiner.Result], java.util.Iterator[CursorJoiner.Result]):
    def __init__(self, cursorLeft: Cursor, columnNamesLeft: java.chaquopy.JavaArray[java.lang.String], cursorRight: Cursor, columnNamesRight: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def hasNext(self) -> bool: ...
    def iterator(self) -> java.util.Iterator[CursorJoiner.Result]: ...
    def next(self) -> CursorJoiner.Result: ...
    def remove(self) -> None: ...

    class Result(java.lang.Enum[CursorJoiner.Result]):
        BOTH: typing.ClassVar[CursorJoiner.Result] = ...
        LEFT: typing.ClassVar[CursorJoiner.Result] = ...
        RIGHT: typing.ClassVar[CursorJoiner.Result] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> CursorJoiner.Result: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[CursorJoiner.Result]: ...

class CursorWindow(android.database.sqlite.SQLiteClosable, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CursorWindow]] = ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, localWindow: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, windowSizeBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    def allocRow(self) -> bool: ...
    def clear(self) -> None: ...
    def copyStringToBuffer(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, buffer: CharArrayBuffer, /) -> None: ...
    def describeContents(self) -> int: ...
    def finalize(self) -> None: ...
    def freeLastRow(self) -> None: ...
    def getBlob(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def getDouble(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> float: ...
    def getFloat(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> float: ...
    def getInt(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getNumRows(self) -> int: ...
    def getShort(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getStartPosition(self) -> int: ...
    def getString(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> str: ...
    def getType(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def isBlob(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isFloat(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isLong(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isNull(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isString(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def newFromParcel(p: android.os.Parcel, /) -> CursorWindow: ...
    def onAllReferencesReleased(self) -> None: ...
    def putBlob(self, value: java.chaquopy.JavaArrayJByte, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def putDouble(self, value: float | java.jdouble | java.lang.Double, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def putLong(self, value: int | java.jlong | java.lang.Long, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def putNull(self, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def putString(self, value: str | java.lang.String, row: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setNumColumns(self, columnNum: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setStartPosition(self, pos: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CursorWindowAllocationException(java.lang.RuntimeException):
    def __init__(self, description: str | java.lang.String, /) -> None: ...

class CursorWrapper(Cursor):
    def __init__(self, cursor: Cursor, /) -> None: ...
    def close(self) -> None: ...
    def copyStringToBuffer(self, columnIndex: int | java.jint | java.lang.Integer, buffer: CharArrayBuffer, /) -> None: ...
    def deactivate(self) -> None: ...
    def getBlob(self, columnIndex: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def getColumnCount(self) -> int: ...
    def getColumnIndex(self, columnName: str | java.lang.String, /) -> int: ...
    def getColumnIndexOrThrow(self, columnName: str | java.lang.String, /) -> int: ...
    def getColumnName(self, columnIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getColumnNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getCount(self) -> int: ...
    def getDouble(self, columnIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getFloat(self, columnIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getInt(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getNotificationUri(self) -> android.net.Uri: ...
    def getNotificationUris(self) -> java.util.List[android.net.Uri]: ...
    def getPosition(self) -> int: ...
    def getShort(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, columnIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getType(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getWantsAllOnMoveCalls(self) -> bool: ...
    def getWrappedCursor(self) -> Cursor: ...
    def isAfterLast(self) -> bool: ...
    def isBeforeFirst(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isFirst(self) -> bool: ...
    def isLast(self) -> bool: ...
    def isNull(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def move(self, offset: int | java.jint | java.lang.Integer, /) -> bool: ...
    def moveToFirst(self) -> bool: ...
    def moveToLast(self) -> bool: ...
    def moveToNext(self) -> bool: ...
    def moveToPosition(self, position: int | java.jint | java.lang.Integer, /) -> bool: ...
    def moveToPrevious(self) -> bool: ...
    def registerContentObserver(self, observer: ContentObserver, /) -> None: ...
    def registerDataSetObserver(self, observer: DataSetObserver, /) -> None: ...
    def requery(self) -> bool: ...
    def respond(self, extras: android.os.Bundle, /) -> android.os.Bundle: ...
    def setExtras(self, extras: android.os.Bundle, /) -> None: ...
    def setNotificationUri(self, cr: android.content.ContentResolver, uri: android.net.Uri, /) -> None: ...
    def setNotificationUris(self, cr: android.content.ContentResolver, uris: java.util.List[android.net.Uri], /) -> None: ...
    def unregisterContentObserver(self, observer: ContentObserver, /) -> None: ...
    def unregisterDataSetObserver(self, observer: DataSetObserver, /) -> None: ...

class DataSetObservable(Observable[DataSetObserver]):
    def __init__(self) -> None: ...
    def notifyChanged(self) -> None: ...
    def notifyInvalidated(self) -> None: ...

class DataSetObserver(java.lang.Object):
    def __init__(self) -> None: ...
    def onChanged(self) -> None: ...
    def onInvalidated(self) -> None: ...

class DatabaseErrorHandler(java.lang.Object):
    def onCorruption(self, arg1: android.database.sqlite.SQLiteDatabase, /) -> None: ...

class DatabaseUtils(java.lang.Object):
    STATEMENT_ABORT: typing.ClassVar[int] = ...
    STATEMENT_ATTACH: typing.ClassVar[int] = ...
    STATEMENT_BEGIN: typing.ClassVar[int] = ...
    STATEMENT_COMMIT: typing.ClassVar[int] = ...
    STATEMENT_DDL: typing.ClassVar[int] = ...
    STATEMENT_OTHER: typing.ClassVar[int] = ...
    STATEMENT_PRAGMA: typing.ClassVar[int] = ...
    STATEMENT_SELECT: typing.ClassVar[int] = ...
    STATEMENT_UNPREPARED: typing.ClassVar[int] = ...
    STATEMENT_UPDATE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def appendEscapedSQLString(sb: java.lang.StringBuilder, sqlString: str | java.lang.String, /) -> None: ...
    @staticmethod
    def appendSelectionArgs(originalValues: java.chaquopy.JavaArray[java.lang.String], newValues: java.chaquopy.JavaArray[java.lang.String], /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def appendValueToSql(sql: java.lang.StringBuilder, value: java.lang.Object | int | bool | float | str, /) -> None: ...
    @staticmethod
    def bindObjectToProgram(prog: android.database.sqlite.SQLiteProgram, index: int | java.jint | java.lang.Integer, value: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    @staticmethod
    def blobFileDescriptorForQuery(prog: android.database.sqlite.SQLiteStatement, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> android.os.ParcelFileDescriptor: ...
    @typing.overload
    @staticmethod
    def blobFileDescriptorForQuery(db: android.database.sqlite.SQLiteDatabase, query: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> android.os.ParcelFileDescriptor: ...
    @staticmethod
    def concatenateWhere(a: str | java.lang.String, b: str | java.lang.String, /) -> str: ...
    @staticmethod
    def createDbFromSqlStatements(context: android.content.Context, dbName: str | java.lang.String, dbVersion: int | java.jint | java.lang.Integer, sqlStatements: str | java.lang.String, /) -> None: ...
    @staticmethod
    def cursorDoubleToContentValues(cursor: Cursor, field: str | java.lang.String, values: android.content.ContentValues, key: str | java.lang.String, /) -> None: ...
    @staticmethod
    def cursorDoubleToContentValuesIfPresent(cursor: Cursor, values: android.content.ContentValues, column: str | java.lang.String, /) -> None: ...
    @staticmethod
    def cursorDoubleToCursorValues(cursor: Cursor, field: str | java.lang.String, values: android.content.ContentValues, /) -> None: ...
    @staticmethod
    def cursorFloatToContentValuesIfPresent(cursor: Cursor, values: android.content.ContentValues, column: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def cursorIntToContentValues(cursor: Cursor, field: str | java.lang.String, values: android.content.ContentValues, /) -> None: ...
    @typing.overload
    @staticmethod
    def cursorIntToContentValues(cursor: Cursor, field: str | java.lang.String, values: android.content.ContentValues, key: str | java.lang.String, /) -> None: ...
    @staticmethod
    def cursorIntToContentValuesIfPresent(cursor: Cursor, values: android.content.ContentValues, column: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def cursorLongToContentValues(cursor: Cursor, field: str | java.lang.String, values: android.content.ContentValues, /) -> None: ...
    @typing.overload
    @staticmethod
    def cursorLongToContentValues(cursor: Cursor, field: str | java.lang.String, values: android.content.ContentValues, key: str | java.lang.String, /) -> None: ...
    @staticmethod
    def cursorLongToContentValuesIfPresent(cursor: Cursor, values: android.content.ContentValues, column: str | java.lang.String, /) -> None: ...
    @staticmethod
    def cursorRowToContentValues(cursor: Cursor, values: android.content.ContentValues, /) -> None: ...
    @staticmethod
    def cursorShortToContentValuesIfPresent(cursor: Cursor, values: android.content.ContentValues, column: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def cursorStringToContentValues(cursor: Cursor, field: str | java.lang.String, values: android.content.ContentValues, /) -> None: ...
    @typing.overload
    @staticmethod
    def cursorStringToContentValues(cursor: Cursor, field: str | java.lang.String, values: android.content.ContentValues, key: str | java.lang.String, /) -> None: ...
    @staticmethod
    def cursorStringToContentValuesIfPresent(cursor: Cursor, values: android.content.ContentValues, column: str | java.lang.String, /) -> None: ...
    @staticmethod
    def cursorStringToInsertHelper(cursor: Cursor, field: str | java.lang.String, inserter: DatabaseUtils.InsertHelper, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def dumpCurrentRow(cursor: Cursor, /) -> None: ...
    @typing.overload
    @staticmethod
    def dumpCurrentRow(cursor: Cursor, stream: java.io.PrintStream, /) -> None: ...
    @typing.overload
    @staticmethod
    def dumpCurrentRow(cursor: Cursor, sb: java.lang.StringBuilder, /) -> None: ...
    @staticmethod
    def dumpCurrentRowToString(cursor: Cursor, /) -> str: ...
    @typing.overload
    @staticmethod
    def dumpCursor(cursor: Cursor, /) -> None: ...
    @typing.overload
    @staticmethod
    def dumpCursor(cursor: Cursor, stream: java.io.PrintStream, /) -> None: ...
    @typing.overload
    @staticmethod
    def dumpCursor(cursor: Cursor, sb: java.lang.StringBuilder, /) -> None: ...
    @staticmethod
    def dumpCursorToString(cursor: Cursor, /) -> str: ...
    @staticmethod
    def getCollationKey(name: str | java.lang.String, /) -> str: ...
    @staticmethod
    def getHexCollationKey(name: str | java.lang.String, /) -> str: ...
    @staticmethod
    def getSqlStatementType(sql: str | java.lang.String, /) -> int: ...
    @typing.overload
    @staticmethod
    def longForQuery(prog: android.database.sqlite.SQLiteStatement, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    @typing.overload
    @staticmethod
    def longForQuery(db: android.database.sqlite.SQLiteDatabase, query: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    @typing.overload
    @staticmethod
    def queryNumEntries(db: android.database.sqlite.SQLiteDatabase, table: str | java.lang.String, /) -> int: ...
    @typing.overload
    @staticmethod
    def queryNumEntries(db: android.database.sqlite.SQLiteDatabase, table: str | java.lang.String, selection: str | java.lang.String, /) -> int: ...
    @typing.overload
    @staticmethod
    def queryNumEntries(db: android.database.sqlite.SQLiteDatabase, table: str | java.lang.String, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    @staticmethod
    def readExceptionFromParcel(reply: android.os.Parcel, /) -> None: ...
    @staticmethod
    def readExceptionWithFileNotFoundExceptionFromParcel(reply: android.os.Parcel, /) -> None: ...
    @staticmethod
    def readExceptionWithOperationApplicationExceptionFromParcel(reply: android.os.Parcel, /) -> None: ...
    @staticmethod
    def sqlEscapeString(value: str | java.lang.String, /) -> str: ...
    @typing.overload
    @staticmethod
    def stringForQuery(prog: android.database.sqlite.SQLiteStatement, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> str: ...
    @typing.overload
    @staticmethod
    def stringForQuery(db: android.database.sqlite.SQLiteDatabase, query: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> str: ...
    @staticmethod
    def writeExceptionToParcel(reply: android.os.Parcel, e: java.lang.Exception, /) -> None: ...

    class InsertHelper(java.lang.Object):
        def __init__(self, db: android.database.sqlite.SQLiteDatabase, tableName: str | java.lang.String, /) -> None: ...
        @typing.overload
        def bind(self, index: int | java.jint | java.lang.Integer, value: float | java.jdouble | java.lang.Double, /) -> None: ...
        @typing.overload
        def bind(self, index: int | java.jint | java.lang.Integer, value: float | java.jfloat | java.lang.Float, /) -> None: ...
        @typing.overload
        def bind(self, index: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def bind(self, index: int | java.jint | java.lang.Integer, value: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def bind(self, index: int | java.jint | java.lang.Integer, value: str | java.lang.String, /) -> None: ...
        @typing.overload
        def bind(self, index: int | java.jint | java.lang.Integer, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        @typing.overload
        def bind(self, index: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def bindNull(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
        def close(self) -> None: ...
        def execute(self) -> int: ...
        def getColumnIndex(self, key: str | java.lang.String, /) -> int: ...
        def insert(self, values: android.content.ContentValues, /) -> int: ...
        def prepareForInsert(self) -> None: ...
        def prepareForReplace(self) -> None: ...
        def replace(self, values: android.content.ContentValues, /) -> int: ...

class DefaultDatabaseErrorHandler(DatabaseErrorHandler):
    def __init__(self) -> None: ...
    def onCorruption(self, dbObj: android.database.sqlite.SQLiteDatabase, /) -> None: ...

class MatrixCursor(AbstractCursor):
    @typing.overload
    def __init__(self, columnNames: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def __init__(self, columnNames: java.chaquopy.JavaArray[java.lang.String], initialCapacity: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addRow(self, columnValues: java.lang.Iterable[java.lang.Object], /) -> None: ...
    @typing.overload
    def addRow(self, columnValues: java.chaquopy.JavaArray[java.lang.Object], /) -> None: ...
    def getBlob(self, column: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def getColumnNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getCount(self) -> int: ...
    def getDouble(self, column: int | java.jint | java.lang.Integer, /) -> float: ...
    def getFloat(self, column: int | java.jint | java.lang.Integer, /) -> float: ...
    def getInt(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getShort(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, column: int | java.jint | java.lang.Integer, /) -> str: ...
    def getType(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def isNull(self, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def newRow(self) -> MatrixCursor.RowBuilder: ...

    class RowBuilder(java.lang.Object):
        @typing.overload
        def add(self, columnValue: java.lang.Object | int | bool | float | str, /) -> MatrixCursor.RowBuilder: ...
        @typing.overload
        def add(self, columnName: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> MatrixCursor.RowBuilder: ...

class MergeCursor(AbstractCursor):
    def __init__(self, cursors: java.chaquopy.JavaArray[Cursor], /) -> None: ...
    def close(self) -> None: ...
    def deactivate(self) -> None: ...
    def getBlob(self, column: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def getColumnNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getCount(self) -> int: ...
    def getDouble(self, column: int | java.jint | java.lang.Integer, /) -> float: ...
    def getFloat(self, column: int | java.jint | java.lang.Integer, /) -> float: ...
    def getInt(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getShort(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, column: int | java.jint | java.lang.Integer, /) -> str: ...
    def getType(self, column: int | java.jint | java.lang.Integer, /) -> int: ...
    def isNull(self, column: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onMove(self, oldPosition: int | java.jint | java.lang.Integer, newPosition: int | java.jint | java.lang.Integer, /) -> bool: ...
    def registerContentObserver(self, observer: ContentObserver, /) -> None: ...
    def registerDataSetObserver(self, observer: DataSetObserver, /) -> None: ...
    def requery(self) -> bool: ...
    def unregisterContentObserver(self, observer: ContentObserver, /) -> None: ...
    def unregisterDataSetObserver(self, observer: DataSetObserver, /) -> None: ...

_Observable__T = typing.TypeVar('_Observable__T')  # <T>
class Observable(java.lang.Object, typing.Generic[_Observable__T]):
    mObservers: java.util.ArrayList[_Observable__T] = ...
    def __init__(self) -> None: ...
    def registerObserver(self, observer: _Observable__T, /) -> None: ...
    def unregisterAll(self) -> None: ...
    def unregisterObserver(self, observer: _Observable__T, /) -> None: ...

class SQLException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class StaleDataException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, description: str | java.lang.String, /) -> None: ...



import typing

import java
import java.chaquopy
import java.lang
import java.math
import java.util.stream

class RandomGenerator(java.lang.Object):
    @typing.overload
    def doubles(self) -> java.util.stream.DoubleStream: ...
    @typing.overload
    def doubles(self, streamSize: int | java.jlong | java.lang.Long, /) -> java.util.stream.DoubleStream: ...
    @typing.overload
    def doubles(self, randomNumberOrigin: float | java.jdouble | java.lang.Double, randomNumberBound: float | java.jdouble | java.lang.Double, /) -> java.util.stream.DoubleStream: ...
    @typing.overload
    def doubles(self, streamSize: int | java.jlong | java.lang.Long, randomNumberOrigin: float | java.jdouble | java.lang.Double, randomNumberBound: float | java.jdouble | java.lang.Double, /) -> java.util.stream.DoubleStream: ...
    @staticmethod
    def getDefault() -> RandomGenerator: ...
    @typing.overload
    def ints(self) -> java.util.stream.IntStream: ...
    @typing.overload
    def ints(self, streamSize: int | java.jlong | java.lang.Long, /) -> java.util.stream.IntStream: ...
    @typing.overload
    def ints(self, randomNumberOrigin: int | java.jint | java.lang.Integer, randomNumberBound: int | java.jint | java.lang.Integer, /) -> java.util.stream.IntStream: ...
    @typing.overload
    def ints(self, streamSize: int | java.jlong | java.lang.Long, randomNumberOrigin: int | java.jint | java.lang.Integer, randomNumberBound: int | java.jint | java.lang.Integer, /) -> java.util.stream.IntStream: ...
    def isDeprecated(self) -> bool: ...
    @typing.overload
    def longs(self) -> java.util.stream.LongStream: ...
    @typing.overload
    def longs(self, streamSize: int | java.jlong | java.lang.Long, /) -> java.util.stream.LongStream: ...
    @typing.overload
    def longs(self, randomNumberOrigin: int | java.jlong | java.lang.Long, randomNumberBound: int | java.jlong | java.lang.Long, /) -> java.util.stream.LongStream: ...
    @typing.overload
    def longs(self, streamSize: int | java.jlong | java.lang.Long, randomNumberOrigin: int | java.jlong | java.lang.Long, randomNumberBound: int | java.jlong | java.lang.Long, /) -> java.util.stream.LongStream: ...
    def nextBoolean(self) -> bool: ...
    def nextBytes(self, bytes: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def nextDouble(self) -> float: ...
    @typing.overload
    def nextDouble(self, bound: float | java.jdouble | java.lang.Double, /) -> float: ...
    @typing.overload
    def nextDouble(self, origin: float | java.jdouble | java.lang.Double, bound: float | java.jdouble | java.lang.Double, /) -> float: ...
    def nextExponential(self) -> float: ...
    @typing.overload
    def nextFloat(self) -> float: ...
    @typing.overload
    def nextFloat(self, bound: float | java.jfloat | java.lang.Float, /) -> float: ...
    @typing.overload
    def nextFloat(self, origin: float | java.jfloat | java.lang.Float, bound: float | java.jfloat | java.lang.Float, /) -> float: ...
    @typing.overload
    def nextGaussian(self) -> float: ...
    @typing.overload
    def nextGaussian(self, mean: float | java.jdouble | java.lang.Double, stddev: float | java.jdouble | java.lang.Double, /) -> float: ...
    @typing.overload
    def nextInt(self) -> int: ...
    @typing.overload
    def nextInt(self, bound: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def nextInt(self, origin: int | java.jint | java.lang.Integer, bound: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def nextLong(self) -> int: ...
    @typing.overload
    def nextLong(self, bound: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def nextLong(self, origin: int | java.jlong | java.lang.Long, bound: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def of(name: str | java.lang.String, /) -> RandomGenerator: ...

    class StreamableGenerator(RandomGenerator):
        @staticmethod
        def of(name: str | java.lang.String, /) -> RandomGenerator.StreamableGenerator: ...
        @typing.overload
        def rngs(self) -> java.util.stream.Stream[RandomGenerator]: ...
        @typing.overload
        def rngs(self, streamSize: int | java.jlong | java.lang.Long, /) -> java.util.stream.Stream[RandomGenerator]: ...

    class SplittableGenerator(RandomGenerator.StreamableGenerator):
        @staticmethod
        def of(name: str | java.lang.String, /) -> RandomGenerator.SplittableGenerator: ...
        @typing.overload
        def rngs(self) -> java.util.stream.Stream[RandomGenerator]: ...
        @typing.overload
        def rngs(self, streamSize: int | java.jlong | java.lang.Long, /) -> java.util.stream.Stream[RandomGenerator]: ...
        @typing.overload
        def split(self) -> RandomGenerator.SplittableGenerator: ...
        @typing.overload
        def split(self, arg1: RandomGenerator.SplittableGenerator, /) -> RandomGenerator.SplittableGenerator: ...
        @typing.overload
        def splits(self) -> java.util.stream.Stream[RandomGenerator.SplittableGenerator]: ...
        @typing.overload
        def splits(self, arg1: int | java.jlong | java.lang.Long, /) -> java.util.stream.Stream[RandomGenerator.SplittableGenerator]: ...
        @typing.overload
        def splits(self, arg1: RandomGenerator.SplittableGenerator, /) -> java.util.stream.Stream[RandomGenerator.SplittableGenerator]: ...
        @typing.overload
        def splits(self, arg1: int | java.jlong | java.lang.Long, arg2: RandomGenerator.SplittableGenerator, /) -> java.util.stream.Stream[RandomGenerator.SplittableGenerator]: ...

    class LeapableGenerator(RandomGenerator.JumpableGenerator):
        def copy(self) -> RandomGenerator.LeapableGenerator: ...
        def copyAndLeap(self) -> RandomGenerator.JumpableGenerator: ...
        def leap(self) -> None: ...
        def leapDistance(self) -> float: ...
        @typing.overload
        def leaps(self) -> java.util.stream.Stream[RandomGenerator.JumpableGenerator]: ...
        @typing.overload
        def leaps(self, streamSize: int | java.jlong | java.lang.Long, /) -> java.util.stream.Stream[RandomGenerator.JumpableGenerator]: ...
        @staticmethod
        def of(name: str | java.lang.String, /) -> RandomGenerator.LeapableGenerator: ...

    class JumpableGenerator(RandomGenerator.StreamableGenerator):
        def copy(self) -> RandomGenerator.JumpableGenerator: ...
        def copyAndJump(self) -> RandomGenerator: ...
        def jump(self) -> None: ...
        def jumpDistance(self) -> float: ...
        @typing.overload
        def jumps(self) -> java.util.stream.Stream[RandomGenerator]: ...
        @typing.overload
        def jumps(self, streamSize: int | java.jlong | java.lang.Long, /) -> java.util.stream.Stream[RandomGenerator]: ...
        @staticmethod
        def of(name: str | java.lang.String, /) -> RandomGenerator.JumpableGenerator: ...
        @typing.overload
        def rngs(self) -> java.util.stream.Stream[RandomGenerator]: ...
        @typing.overload
        def rngs(self, streamSize: int | java.jlong | java.lang.Long, /) -> java.util.stream.Stream[RandomGenerator]: ...

    class ArbitrarilyJumpableGenerator(RandomGenerator.LeapableGenerator):
        def copy(self) -> RandomGenerator.ArbitrarilyJumpableGenerator: ...
        def copyAndJump(self, distance: float | java.jdouble | java.lang.Double, /) -> RandomGenerator.ArbitrarilyJumpableGenerator: ...
        @typing.overload
        def jump(self) -> None: ...
        @typing.overload
        def jump(self, arg1: float | java.jdouble | java.lang.Double, /) -> None: ...
        def jumpPowerOfTwo(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def jumps(self, distance: float | java.jdouble | java.lang.Double, /) -> java.util.stream.Stream[RandomGenerator.ArbitrarilyJumpableGenerator]: ...
        @typing.overload
        def jumps(self, streamSize: int | java.jlong | java.lang.Long, distance: float | java.jdouble | java.lang.Double, /) -> java.util.stream.Stream[RandomGenerator.ArbitrarilyJumpableGenerator]: ...
        def leap(self) -> None: ...
        @staticmethod
        def of(name: str | java.lang.String, /) -> RandomGenerator.ArbitrarilyJumpableGenerator: ...

_RandomGeneratorFactory__T = typing.TypeVar('_RandomGeneratorFactory__T')  # <T>
class RandomGeneratorFactory(java.lang.Object, typing.Generic[_RandomGeneratorFactory__T]):
    @staticmethod
    def all() -> java.util.stream.Stream[RandomGeneratorFactory[RandomGenerator]]: ...
    @typing.overload
    def create(self) -> _RandomGeneratorFactory__T: ...
    @typing.overload
    def create(self, seed: int | java.jlong | java.lang.Long, /) -> _RandomGeneratorFactory__T: ...
    @typing.overload
    def create(self, seed: java.chaquopy.JavaArrayJByte, /) -> _RandomGeneratorFactory__T: ...
    def equidistribution(self) -> int: ...
    @staticmethod
    def getDefault() -> RandomGeneratorFactory[RandomGenerator]: ...
    def group(self) -> str: ...
    def isArbitrarilyJumpable(self) -> bool: ...
    def isDeprecated(self) -> bool: ...
    def isHardware(self) -> bool: ...
    def isJumpable(self) -> bool: ...
    def isLeapable(self) -> bool: ...
    def isSplittable(self) -> bool: ...
    def isStatistical(self) -> bool: ...
    def isStochastic(self) -> bool: ...
    def isStreamable(self) -> bool: ...
    def name(self) -> str: ...
    @staticmethod
    def of(name: str | java.lang.String, /) -> RandomGeneratorFactory[java.lang.Object]: ...
    def period(self) -> java.math.BigInteger: ...
    def stateBits(self) -> int: ...
